==> middle-0.2.2.tar.gz: middle-0.2.2/tests/test_compat_types.py <==
import datetime
import typing
from decimal import Decimal
from enum import Enum
from enum import EnumMeta

import pytest

import middle


@pytest.mark.parametrize(
    "type_,expected",
    [
        pytest.param(None, type(None), id="none"),
        pytest.param(str, str, id="str"),
        pytest.param(int, int, id="int"),
        pytest.param(float, float, id="float"),
        pytest.param(bool, bool, id="bool"),
        pytest.param(bytes, bytes, id="bytes"),
        pytest.param(datetime.date, datetime.date, id="datetime_date"),
        pytest.param(
            datetime.datetime, datetime.datetime, id="datetime_datetime"
        ),
        pytest.param(Decimal, Decimal, id="Decimal"),
        pytest.param(typing.Dict, typing.Dict, id="typing.Dict"),
        pytest.param(
            typing.Dict[str, float], typing.Dict, id="typing.Dict[str,float]"
        ),
        pytest.param(typing.List, typing.List, id="typing.List"),
        pytest.param(typing.List[int], typing.List, id="typing.List[int]"),
        pytest.param(typing.Set, typing.Set, id="typing.Set"),
        pytest.param(typing.Set[float], typing.Set, id="typing.Set[float]"),
        pytest.param(typing.Tuple, typing.Tuple, id="typing.Tuple"),
        pytest.param(
            typing.Tuple[Decimal, float, None, int],
            typing.Tuple,
            id="typing.Tuple[Decimal,float,None,int]",
        ),
        pytest.param(typing.Union, typing.Union, id="typing.Union"),
        pytest.param(
            typing.Union[str, int], typing.Union, id="typing.Union[str,int]"
        ),
        pytest.param(
            typing.Optional[str], typing.Union, id="typing.Union[str,None]"
        ),
    ],
)
def test_get_type(type_, expected):
    assert middle.get_type(type_) == expected


def test_get_enum():
    class RegionEnum(str, Enum):
        TROPICAL = "TROPICAL"
        TEMPERATE = "TEMPERATE"
        BOREAL = "BOREAL"

    assert middle.get_type(RegionEnum) == EnumMeta


def test_registered_custom_type():
    class Foo:
        pass

    middle.TypeRegistry[Foo] = Foo
    assert middle.get_type(Foo) == Foo


def test_unregistered_custom_type():
    class Bar:
        pass

    assert middle.get_type(Bar) == Bar

==> middle-0.2.4.tar.gz: middle-0.2.4/tests/test_compat_types.py <==
import datetime
import typing as t

from decimal import Decimal
from enum import Enum, EnumMeta

import pytest

import middle


@pytest.mark.parametrize(
    "type_,expected",
    [
        pytest.param(None, type(None), id="none"),
        pytest.param(str, str, id="str"),
        pytest.param(int, int, id="int"),
        pytest.param(float, float, id="float"),
        pytest.param(bool, bool, id="bool"),
        pytest.param(bytes, bytes, id="bytes"),
        pytest.param(datetime.date, datetime.date, id="datetime_date"),
        pytest.param(
            datetime.datetime, datetime.datetime, id="datetime_datetime"
        ),
        pytest.param(Decimal, Decimal, id="Decimal"),
        pytest.param(t.Dict, t.Dict, id="typing.Dict"),
        pytest.param(t.Dict[str, float], t.Dict, id="typing.Dict[str,float]"),
        pytest.param(t.List, t.List, id="typing.List"),
        pytest.param(t.List[int], t.List, id="typing.List[int]"),
        pytest.param(t.Set, t.Set, id="typing.Set"),
        pytest.param(t.Set[float], t.Set, id="typing.Set[float]"),
        pytest.param(t.Tuple, t.Tuple, id="typing.Tuple"),
        pytest.param(
            t.Tuple[Decimal, float, None, int],
            t.Tuple,
            id="typing.Tuple[Decimal,float,None,int]",
        ),
        pytest.param(t.Union, t.Union, id="typing.Union"),
        pytest.param(t.Union[str, int], t.Union, id="typing.Union[str,int]"),
        pytest.param(t.Optional[str], t.Union, id="typing.Union[str,None]"),
    ],
)
def test_get_type(type_, expected):
    assert middle.get_type(type_) == expected


def test_get_enum():
    class RegionEnum(str, Enum):
        TROPICAL = "TROPICAL"
        TEMPERATE = "TEMPERATE"
        BOREAL = "BOREAL"

    assert middle.get_type(RegionEnum) == EnumMeta


def test_registered_custom_type():
    class Foo:
        pass

    middle.TypeRegistry[Foo] = Foo
    assert middle.get_type(Foo) == Foo


def test_unregistered_custom_type():
    class Bar:
        pass

    assert middle.get_type(Bar) == Bar
